@@ -15,14 +15,11 @@ available = {
 def get_path(dset: str) -> str:
     """
     Get the path to the data file.
-    Parameters
-    ----------
-    dset : str
-        The name of the dataset. See ``geoutils.datasets.available`` for
-        all options.
-    Examples
-    --------
-    >>> geoutils.datasets.get_path("landsat_B4")
+    :param dset: The name of the dataset. See ``geoutils.datasets.available`` for all options.
+
+    :examples:
+        >>> geoutils.datasets.get_path("landsat_B4")
+
     """
     if dset in list(available.keys()):
         return os.path.abspath(os.path.join(_module_path, available[dset]))
